.. mat_discover documentation master file, created by
   sphinx-quickstart on Fri Nov  5 01:44:19 2021.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to Chemically Novel Materials Discovery!
================================================

This is the documentation for `mat_discover <https://github.com/sparks-baird/mat_discover>`_. Descending from Stochastic Clustering Variance Regression (DiSCoVeR) is a
composition-based materials
discovery algorithm. DiSCoVeR emphasizes exploring high-performance candidates in new chemical
spaces as originally proposed by Baird, Diep, and Sparks (`Digital Discovery <https://dx.doi.org/10.1039/D1DD00028D>`_, `ChemRxiv <https://dx.doi.org/10.33774/chemrxiv-2021-5l2f8-v3>`_). The
library :code:`mat_discover` provides a GPU-accelerated (and CPU-compatible) Python
implementation and tools for analyzing the outputs. :code:`mat_discover` will "suggest your next experiment" using a custom training dataset of chemical formula and target
properties and a custom validation set of potential candidates. All in just a few lines of code! `Get started learning about DiSCoVeR <https://mat-discover.readthedocs.io/en/latest/readme.html>`_.

.. raw:: html

   <a class="github-button" href="https://github.com/sparks-baird/mat_discover"
   data-icon="octicon-star" data-size="large" data-show-count="true" aria-label="Star
   sparks-baird/mat_discover on GitHub">Star</a>
   <a class="github-button"
   href="https://github.com/sgbaird" data-size="large" data-show-count="true"
   aria-label="Follow @sgbaird on GitHub">Follow @sgbaird</a>
   <a class="github-button" href="https://github.com/sparks-baird/mat_discover/issues"
   data-icon="octicon-issue-opened" data-size="large" data-show-count="true"
   aria-label="Issue sparks-baird/mat_discover on GitHub">Issue</a>
   <a class="github-button" href="https://github.com/sparks-baird/mat_discover/discussions" data-icon="octicon-comment-discussion" data-size="large" aria-label="Discuss sparks-baird/mat_discover on GitHub">Discuss</a>
   <br><br>

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   readme
   examples
   figures
   contributing
   modules

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

.. raw:: html

   <script async defer src="https://buttons.github.io/buttons.js"></script>
